@@ -108,7 +108,7 @@ class EdgeIdField(serializers.Field):
 
 class SavedGraphSerializer(serializers.ModelSerializer):
     user = serializers.HiddenField(default=serializers.CurrentUserDefault())
-    edges = serializers.ListField(child=EdgeIdField())
+    edges = serializers.ListField(child=EdgeIdField(), allow_empty=False)
     name = serializers.CharField()
     created_at = serializers.DateTimeField(
         required=False,
