@@ -86,9 +86,11 @@ class SavedGraphViewSet(GraphDbMixin, viewsets.ModelViewSet):
 
     def retrieve(self, request, pk=None):
         response = super().retrieve(request, pk=pk)
-        edges_ids = get_object_or_404(SavedGraph, user=request.user, pk=pk).edges
-        nodes, edges = self.graph.get_by_many_edges(edges_ids)
-        graph_data = self.serialize_graph(nodes, edges)
+        if edges_ids := get_object_or_404(SavedGraph, user=request.user, pk=pk).edges:
+            nodes, edges = self.graph.get_by_many_edges(edges_ids)
+            graph_data = self.serialize_graph(nodes, edges)
+        else:
+            graph_data = {"nodes": [], "edges": []}
         response.data["nodes"] = graph_data["nodes"]
         response.data["edges"] = graph_data["edges"]
         return response
@@ -97,13 +99,9 @@ class SavedGraphViewSet(GraphDbMixin, viewsets.ModelViewSet):
 class SavedGraphDetails(GraphDbMixin, APIView):
     def get(self, request, *args, **kwargs):
         graph_pk = kwargs.pop("pk")
-        edges_ids = get_object_or_404(
-            SavedGraph,
-            user=request.user,
-            pk=graph_pk,
-        ).edges
-
-        nodes, edges = self.graph.get_by_many_edges(edges_ids)
+        nodes, edges = [], []
+        if edges_ids := get_object_or_404(SavedGraph, user=request.user, pk=graph_pk).edges:
+            nodes, edges = self.graph.get_by_many_edges(edges_ids)
         return Response(self.serialize_graph(nodes, edges))
 
 
